@@ -7,7 +7,7 @@
 ################################
 
 spher.cor <- function(x, y) {
-  ## x and y are two spherical variables
+  ## x and y are two (hyper-)spherical variables
   x <- as.matrix(x)
   y <- as.matrix(y)
   x <- x/sqrt(rowSums(x^2))
@@ -18,11 +18,11 @@ spher.cor <- function(x, y) {
   x <- apply(x, 2, stand)  ## subtract the mean
   y <- apply(y, 2, stand)  ## subtract the mean
   n <- nrow(x)  ## sample size
-  s11 <- crossprod(x)/n
-  s12 <- ( t(x) %*% y )/n
-  s21 <- t(s12)/n
-  s22 <- crossprod(y)/n
-  rsq <- sum( diag(solve(s11) %*% s12 %*% solve(s22) %*% s21) )
+  s11 <- crossprod(x) / n
+  s12 <- crossprod( x, y ) / n
+  s21 <- t( s12 )
+  s22 <- crossprod(y) / n
+  rsq <- sum( diag(solve(s11, s12) %*% solve(s22, s21)) )
   test <- n * rsq
   pvalue <- 1 - pchisq(test, p * q)
   res <- c(rsq, pvalue)
